cal.EventPolicy (Recurrency policy) — amici1

# `cal.EventPolicy` (Recurrency policy)

EventPolicy(id, start_date, start_time, end_date, end_time, name, every_unit, every, positions, monday, tuesday, wednesday, thursday, friday, saturday, sunday, max_events, event_type, name_de, name_fr)

Master tables : cal.EventPolicies (Recurrency policies)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Start date (start_date) : The start date of the first meeting to be generated.

- Start time (start_time) : See `<lino.core.fields.TimeField: start_time>`.

- End Date (end_date) : The end date of the first meeting to be generated. Leave this field empty if the meetings last less than one day.

- End Time (end_time) : See `<lino.core.fields.TimeField: end_time>`.

- Designation (name) : See `<lino.utils.mldbc.fields.BabelCharField: name>`.

- Recurrency (every_unit) : The interval between each periodic iteration.

- Repeat every (every) : The frequency of periodic iteration: daily, weekly, monthly or yearly.

- Positions (positions) : Space-separated list of one or several positions within the recurrency cycle.

- Monday (monday) : See `<django.db.models.fields.BooleanField: monday>`.

- Tuesday (tuesday) : See `<django.db.models.fields.BooleanField: tuesday>`.

- Wednesday (wednesday) : See `<django.db.models.fields.BooleanField: wednesday>`.

- Thursday (thursday) : See `<django.db.models.fields.BooleanField: thursday>`.

- Friday (friday) : See `<django.db.models.fields.BooleanField: friday>`.

- Saturday (saturday) : See `<django.db.models.fields.BooleanField: saturday>`.

- Sunday (sunday) : See `<django.db.models.fields.BooleanField: sunday>`.

- Number of events (max_events) : Maximum number of calendar entries to generate.

- Calendar entry type (event_type) : Generated calendar entries will have this type.

- Designation (de) (name_de) : See `<django.db.models.fields.CharField: name_de>`.

- Designation (fr) (name_fr) : See `<django.db.models.fields.CharField: name_fr>`.

- Name (name_column) : See `lino_xl.lib.cal.models.EventPolicy.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.cal.models.EventPolicy.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.cal.models.EventPolicy.overview`.

- Description (what_text) : See `lino_xl.lib.cal.models.EventPolicy.what_text`.

- Times (times_text) : See `lino_xl.lib.cal.models.EventPolicy.times_text`.

- When (weekdays_text) : A virtual field returning the textual formulation of the weekdays where the recurrence occurs.

- Duration (duration) : See `lino_xl.lib.cal.models.EventPolicy.duration`.

Referenced from

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
start_date | Start date | The start date of the first meeting to be generated.
start_time | Start time |
end_date | End Date | The end date of the first meeting to be generated. Leave this field empty if the meetings last less than one day.
end_time | End Time |
name | Designation |
every_unit | Recurrency | The interval between each periodic iteration.
every | Repeat every | The frequency of periodic iteration: daily, weekly, monthly or yearly.
positions | Positions | Space-separated list of one or several positions within the recurrency cycle.
monday | Monday |
tuesday | Tuesday |
wednesday | Wednesday |
thursday | Thursday |
friday | Friday |
saturday | Saturday |
sunday | Sunday |
max_events | Number of events | Maximum number of calendar entries to generate.
event_type | Calendar entry type | Generated calendar entries will have this type.
name_de | Designation (de) |
name_fr | Designation (fr) |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |
what_text | Description |
times_text | Times |
weekdays_text | When | A virtual field returning the textual formulation of the weekdays where the recurrence occurs.
duration | Duration |